<?php
/**
 *
 * @author  YIThemes
 * @package YITH WordPress Title Bar Effects
 * @version 1.0.0
 */
if ( !defined( 'YITH_WTBE' ) ) {
    exit;
} // Exit if accessed directly

if( !class_exists( 'YITH_WTBE_Admin' ) ) {
    class YITH_WTBE_Admin{
        /**
         * Single instance of the class
         *
         * @var \YITH_WTBE
         * @since 1.0.0
         */
        protected static $instance;

        /**
         * @var $_panel Panel Object
         */
        protected $_panel;

        /**
        * @var string Official plugin documentation
        */
        protected $_official_documentation = 'http://yithemes.com/docs-plugins/yith-wordpress-title-bar-effects/' ;

        /**
         * @var string Official plugin landing page
         */
        protected $_premium_landing_url = 'http://yithemes.com/themes/plugins/yith-wordpress-title-bar-effects/' ;

        /**
         * @var string Official plugin landing page
         */
        protected $_premium_live_demo = 'http://plugins.yithemes.com/yith-wordpress-title-bar-effects/' ;



        /**
         * @var string panel page
         */
        protected $_panel_page = 'yith_wtbe_panel';
        

        /**
         * Returns single instance of the class
         *
         * @return \YITH_WTBE
         * @since 1.0.0
         */
        public static function get_instance()
        {
            if (is_null(self::$instance)) {
                self::$instance = new self;
            }

            return self::$instance;
        }

        public function __construct()
        {
            
            add_action( 'admin_menu', array( $this, 'register_panel' ),5 );
            add_action( 'add_meta_boxes', array($this,'register_meta_boxes') );
            add_action( 'save_post',array($this,'save_post_meta') );

            add_filter( 'plugin_action_links_' . plugin_basename( YITH_WTBE_DIR . '/' . basename( YITH_WTBE_FILE ) ), array( $this, 'action_links' ) );
            add_filter( 'plugin_row_meta', array( $this, 'plugin_row_meta' ), 10, 4 );
            
            // register plugin to licence/update system
            add_action( 'wp_loaded', array( $this, 'register_plugin_for_activation' ), 99 );
            add_action( 'admin_init', array( $this, 'register_plugin_for_updates' ) );
        }

        /**
         * Add a panel under YITH Plugins tab
         *
         * @return   void
         * @since    1.0
         * @author   Torrisi Alessio <alessio.torrisi.91@gmail.com>
         * @use      /Yit_Plugin_Panel class
         * @see      plugin-fw/lib/yit-plugin-panel.php
         */
        public function register_panel() {

            if ( !empty( $this->_panel ) ) {
                return;
            }

            $admin_tabs = array(
                'settings'  =>  __( 'Settings', 'yith-wordpress-title-bar-effects' ),
            );

            $args = array(
                'create_menu_page' => true,
                'parent_slug'      => '',
                'page_title'       => _x( 'Title Bar Effects', 'plugin name in admin page title', 'yith-wordpress-title-bar-effects' ),
                'menu_title'       => _x( 'Title Bar Effects', 'plugin name in admin WP menu', 'yith-wordpress-title-bar-effects' ),
                'capability'       => 'manage_options',
                'page'             => $this->_panel_page,
                'parent'           => 'ywtbe',
                'parent_page'      => 'yit_plugin_panel',
                'admin-tabs'       => $admin_tabs,
                'options-path'     => YITH_WTBE_DIR . '/plugin-options'
            );

            /* === Fixed: not updated theme  === */
            if ( !class_exists( 'YIT_Plugin_Panel' ) ) {
                require_once( YITH_WTBE_DIR.'/plugin-fw/lib/yit-plugin-panel.php' );
            }
            
            $this->_panel = new YIT_Plugin_Panel( $args );
        }

          /**
         * add custom action links
         * @author YITHEMES
         * @since 1.0.0
         * @param $links
         * @return array
         */
        public function action_links( $links ){
            
            $links[] = '<a href="' . admin_url( "admin.php?page={$this->_panel_page}" ) . '">' . __( 'Settings', 'yith-wordpress-title-bar-effects' ) . '</a>';

            $premium_live_text =  __( 'Live demo', 'yith-wordpress-title-bar-effects' );

            $links[] = '<a href="' . $this->_premium_live_demo . '" target="_blank">' . $premium_live_text . '</a>';


            return $links;
        }

        /**
         * add custom plugin meta
         * @author YITHEMES
         * @since 1.0.0
         * @param $plugin_meta
         * @param $plugin_file
         * @param $plugin_data
         * @param $status
         * @return array
         */
        public function plugin_row_meta( $plugin_meta, $plugin_file, $plugin_data, $status ){

            if( defined('YITH_WTBE_INIT') && YITH_WTBE_INIT === $plugin_file ){


                $plugin_meta[] = '<a href="' . $this->_official_documentation . '" target="_blank">' . __( 'Plugin documentation', 'yith-wordpress-title-bar-effects' ) . '</a>';
            }

            return $plugin_meta;
        }

        /**
         *  Register metabox Title Bar Effects into post, page and product
         *
         * @return   void
         * @since    1.0
         * @author   Torrisi Alessio <alessio.torrisi.91@gmail.com>
         */
        public function register_meta_boxes() {
            add_meta_box(
                'yith_wtbe_title_bar_mb',
                __( 'YITH WordPress Title Bar Effects','yith-wordpress-title-bar-effects' ),
                array($this,'print_post_meta'),
                array('post','page','product'),
                'normal',
                'default'
            );
        }



        /**
         *  Print post meta in metabox Title Bar effects
         *
         * @return   void
         * @since    1.0
         * @author   Torrisi Alessio <alessio.torrisi.91@gmail.com>
         */
        public function print_post_meta() {
            global $post;
            $title = get_post_meta( $post->ID, '_yith_wtbe_title_bar',true );
            $title_prefix = get_post_meta( $post->ID, '_yith_wtbe_title_bar_prefix',true );
            $title_suffix = get_post_meta( $post->ID, '_yith_wtbe_title_bar_suffix',true );
            echo sprintf( __('%1$sTitle displayed on the tab when the animation is applied%2$s','yith-wordpress-title-bar-effects'),'<p>','</p>');
            echo '<input id="yith_wptbe_title_bar" name="yith_wptbe_title_bar" value="'.$title.'" style="width: 100%; padding:10px">';
            echo sprintf( __('%1$sTitle prefix%2$s','yith-wordpress-title-bar-effects'),'<p>','</p>');
            echo '<input id="yith_wptbe_title_bar_prefix" name="yith_wptbe_title_bar_prefix" value="'.$title_prefix.'" style="width: 100%; padding:10px">';
            echo sprintf( __('%1$sTitle suffix%2$s','yith-wordpress-title-bar-effects'),'<p>','</p>');
            echo '<input id="yith_wptbe_title_bar_suffix" name="yith_wptbe_title_bar_suffix" value="'.$title_suffix.'" style="width: 100%; padding:10px">';

        }


        /** Save post meta
         *
         * @return   void
         * @since    1.0
         * @author   Torrisi Alessio <alessio.torrisi.91@gmail.com>
         */
        public function save_post_meta(){
            global $post;
            if( isset( $_POST['yith_wptbe_title_bar'] ) ){
                update_post_meta($post->ID,'_yith_wtbe_title_bar', $_POST['yith_wptbe_title_bar']);
            }
            if( isset( $_POST['yith_wptbe_title_bar_prefix'] ) ){
                update_post_meta($post->ID,'_yith_wtbe_title_bar_prefix', $_POST['yith_wptbe_title_bar_prefix']);
            }
            if( isset( $_POST['yith_wptbe_title_bar_suffix'] ) ){
                update_post_meta($post->ID,'_yith_wtbe_title_bar_suffix', $_POST['yith_wptbe_title_bar_suffix']);
            }
        }

        /**
         * Register plugins for activation tab
         *
         * @return void
         * @since    1.0.0
         * @author   Alessio Torrisi <alessio.torrisi@yourinspiration.it>
         */
        public function register_plugin_for_activation() {
            if ( ! class_exists( 'YIT_Plugin_Licence' ) ) {
                require_once( YITH_WTBE_DIR . 'plugin-fw/lib/yit-plugin-licence.php' );
            }

            YIT_Plugin_Licence()->register( YITH_WTBE_INIT, YITH_WTBE_SECRET_KEY, YITH_WTBE_SLUG );
        }

        /**
         * Register plugins for update tab
         *
         * @return void
         * @since    1.0.0
         * @author   Alessio Torrisi <alessio.torrisi@yourinspiration.it>
         */
        public function register_plugin_for_updates() {
            if ( ! class_exists( 'YIT_Upgrade' ) ) {
                require_once( YITH_WTBE_DIR . 'plugin-fw/lib/yit-upgrade.php' );
            }

            YIT_Upgrade()->register( YITH_WTBE_SLUG, YITH_WTBE_INIT );
        }

    }
}


/**
 * Unique access to instance of YITH_WTBE_Admin class
 *
 * @return \YITH_WTBE_Admin
 * @since 1.0.0
 */
function YITH_WTBE_Admin() {
    return YITH_WTBE_Admin::get_instance();
}